@@ -1,12 +1,16 @@
 import argparse
 
+
 class CliCommand:
     @staticmethod
     def help():
         return None
 
     def setup_parser(self, parser: argparse.ArgumentParser):
-        pass
+        raise NotImplemented
 
     def run(self, args):
-        pass
+        raise NotImplemented
+
+    def handle_exception(self, exception: Exception):
+        raise exception
