@@ -4,7 +4,7 @@ import os
 import argparse
 from auterioncli.commands import available_commands
 
-from auterioncli.meta_util import PersistentState, check_for_updates, get_version
+from auterioncli.meta_util import PersistentState, check_for_updates, get_version, eprint
 
 def main():
 
@@ -35,7 +35,15 @@ def main():
 
     check_for_updates(persistent_state)
 
-    commands[args.root_command].run(args)
+    try:
+        # Run command
+        commands[args.root_command].run(args)
+    except Exception as e:
+        # Give command modules as chance to handle their exceptions
+        commands[args.root_command].handle_exception(e)
+    except KeyboardInterrupt:
+        eprint("Aborting..")
+        exit(1)
 
     persistent_state.persist()
 
